#
# spec file for package uyuni-common-libs
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global debug_package %{nil} 

%if 0%{?fedora} || 0%{?suse_version} >= 1500 || 0%{?rhel} >= 8
%{!?python3_sitelib: %global python3_sitelib %(%{__python3} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%global python3root %{python3_sitelib}/uyuni
%global build_py3 1
%endif

%if ( 0%{?rhel} && 0%{?rhel} < 8 ) || 0%{?suse_version}
%global build_py2   1
%endif

%define pythonX %{?build_py3:python3}%{!?build_py3:python}

%if 0%{?suse_version} >= 1500
%global python_prefix python3
%else
%if  0%{?fedora} >= 28  || 0%{?rhel} >= 8
%global python_prefix python2
%else
%global python_prefix python
%endif
%endif

%{!?python2_sitelib: %global python2_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%global python2root %{python2_sitelib}/uyuni

Name:           uyuni-common-libs
Summary:        Uyuni server and client libs
License:        GPL-2.0-only
Group:          Development/Languages/Python
Version:        4.2.5
Release:    1.15.1
Url:            https://github.com/uyuni-project/uyuni
Source0: uyuni-common-libs-git-0.9352165.tar.gz
BuildRequires:  fdupes
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Uyuni server and client libs

%if 0%{?build_py2}
%package -n python2-%{name}
Summary:        Uyuni server and client tools libraries for python2
Group:          Development/Languages/Python
Requires:       python
%if 0%{?suse_version}
BuildRequires:  python-devel
%else
BuildRequires:  python2-devel
%endif

%description -n python2-%{name}
Python 2 libraries required by both Uyuni server and client tools.
%endif

%if 0%{?build_py3}
%package -n python3-%{name}
Summary:        Uyuni server and client tools libraries for python3
Group:          Development/Languages/Python
BuildRequires:  python3-devel
Conflicts:      %{name} < 1.7.0
%if 0%{?suse_version}
Requires:       python3-base
%else
Requires:       python3-libs
%endif

Obsoletes:      python3-spacewalk-usix
Obsoletes:      python3-spacewalk-backend-libs

%description -n python3-%{name}
Python 3 libraries required by both Uyuni server and client tools.
%endif

%prep
%setup -q -n uyuni-common-libs-git-0.9352165

%build
make -f Makefile.common-libs all PYTHON_BIN=%{pythonX}


%install
make -f Makefile.common-libs install PREFIX=$RPM_BUILD_ROOT \
    MANDIR=%{_mandir} PYTHON_BIN=%{pythonX}

%if 0%{?build_py3}
install -d $RPM_BUILD_ROOT%{python2root}/common
cp $RPM_BUILD_ROOT%{python3root}/__init__.py \
    $RPM_BUILD_ROOT%{python2root}/
cp $RPM_BUILD_ROOT%{python3root}/common/*.py \
    $RPM_BUILD_ROOT%{python2root}/common
%endif

%if 0%{?suse_version}
%if 0%{?build_py2}
%py_compile -O %{buildroot}/%{python2root}
%fdupes %{buildroot}/%{python2root}
%endif
%if 0%{?build_py3}
%py3_compile -O %{buildroot}/%{python3root}
%fdupes %{buildroot}/%{python3root}
%endif
%endif

%if !(0%{?build_py2})
rm -Rf $RPM_BUILD_ROOT%{python2root}
%endif

%if 0%{?build_py2}
%files -n python2-%{name}
%defattr(-,root,root)
%doc LICENSE
%{python2root}
%endif

%if 0%{?build_py3}
%files -n python3-%{name}
%defattr(-,root,root)
%doc LICENSE
%{python3root}
%endif

%changelog
* Fri Jul 16 2021 jgonzalez@suse.com
- version 4.2.5-1
- Handle broken RPM packages to prevent exceptions
  causing fails on repository synchronization (bsc#1186650)
- Adapt the tests to the new images
* Fri May 28 2021 jgonzalez@suse.com
- version 4.2.4-1
- Maintainer field in debian packages are only recommended (bsc#1186508)
* Wed Jan 27 2021 jgonzalez@suse.com
- version 4.2.3-1
- Section in Debian packages in now treated as optional (bsc#1179555)
* Wed Nov 25 2020 jgonzalez@suse.com
- version 4.2.2-1
- Cleaning up unused Python 2 build leftovers.
- Disabled debug package build.
* Fri Sep 18 2020 jgonzalez@suse.com
- version 4.2.1-1
- Fix issues importing RPM packages with long RPM headers (bsc#1174965)
- Update package version to 4.2.0
* Wed May 20 2020 jgonzalez@suse.com
- version 4.1.5-1
- uyuni-common-libs obsoletes python3-spacewalk-usix and
  python3-spacewalk-backend-libs (bsc#1170684)
- reposync speedup fixes
* Mon Apr 13 2020 jgonzalez@suse.com
- version 4.1.4-1
- implement notification utility
- Do not break when syncing Oracle 7 yum channel (bsc#1158463)
* Thu Mar 19 2020 jgonzalez@suse.com
- version 4.1.3-1
- Add MODULARITYLABEL tag support
* Wed Jan 22 2020 jgonzalez@suse.com
- version 4.1.2-1
- remove conflicts to spacewalk-backend-libs packages
* Wed Nov 27 2019 jgonzalez@suse.com
- version 4.1.1-1
- Fix building for CentOS6/RHEL6/Expanded Support 6
- add conflicts to spacewalk-backend-libs and spacewalk-usix to
  remove them on update
* Fri Nov  1 2019 mc@suse.com
- initial release
- replaces spacewalk-backend-libs and spacewalk-usix
